"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.messages = exports.ruleName = undefined;

exports.default = function (actual, options) {
  return function (root, result) {
    var validOptions = (0, _utils.validateOptions)(result, ruleName, { actual: actual }, {
      actual: options,
      possible: {
        ignoreProperties: [_lodash2.default.isString],
        checkPrefixed: _lodash2.default.isBoolean
      },
      optional: true
    });

    if (!validOptions) {
      return;
    }

    var shouldCheckPrefixed = _lodash2.default.get(options, "checkPrefixed");

    root.walkDecls(function (decl) {
      var prop = decl.prop;


      if (!(0, _utils.isStandardSyntaxProperty)(prop)) {
        return;
      }
      if (!(0, _utils.isStandardSyntaxDeclaration)(decl)) {
        return;
      }
      if ((0, _utils.isCustomProperty)(prop)) {
        return;
      }

      if (!shouldCheckPrefixed && _postcss.vendor.prefix(prop)) {
        return;
      }

      if ((0, _utils.optionsMatches)(options, "ignoreProperties", prop)) {
        return;
      }

      if (_knownCssProperties.all.indexOf(prop.toLowerCase()) !== -1) {
        return;
      }

      (0, _utils.report)({
        message: messages.rejected(prop),
        node: decl,
        result: result,
        ruleName: ruleName
      });
    });
  };
};

var _utils = require("../../utils");

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _knownCssProperties = require("known-css-properties");

var _postcss = require("postcss");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ruleName = exports.ruleName = "property-no-unknown";

var messages = exports.messages = (0, _utils.ruleMessages)(ruleName, {
  rejected: function rejected(property) {
    return "Unexpected unknown property \"" + property + "\"";
  }
});